@@ -19,6 +19,7 @@
 package org.wildfly.common;
 
 import java.util.Collection;
+import java.util.Map;
 
 import org.wildfly.common._private.CommonMessages;
 import org.wildfly.common.annotation.NotNull;
@@ -120,6 +121,150 @@ public final class Assert {
         return value;
     }
 
+    /**
+     * Check that the named parameter is not empty.  Use a standard exception message if it is.
+     *
+     * @param name the parameter name
+     * @param value the parameter value
+     * @return the value that was passed in
+     * @throws IllegalArgumentException if the value is empty
+     */
+    @NotNull
+    public static <K, V, T extends Map<K, V>> T checkNotEmptyParam(String name, T value) {
+        checkNotNullParamChecked("name", name);
+        checkNotNullParamChecked("value", value);
+        if (value.isEmpty()) throw CommonMessages.msg.emptyParam(name);
+        return value;
+    }
+
+    /**
+     * Check that the named parameter is not empty.  Use a standard exception message if it is.
+     *
+     * @param name the parameter name
+     * @param value the parameter value
+     * @return the value that was passed in
+     * @throws IllegalArgumentException if the value is empty
+     */
+    @NotNull
+    public static <T> T[] checkNotEmptyParam(String name, T[] value) {
+        checkNotNullParamChecked("name", name);
+        checkNotNullParamChecked("value", value);
+        if (value.length == 0) throw CommonMessages.msg.emptyParam(name);
+        return value;
+    }
+
+    /**
+     * Check that the named parameter is not empty.  Use a standard exception message if it is.
+     *
+     * @param name the parameter name
+     * @param value the parameter value
+     * @return the value that was passed in
+     * @throws IllegalArgumentException if the value is empty
+     */
+    @NotNull
+    public static boolean[] checkNotEmptyParam(String name, boolean[] value) {
+        checkNotNullParamChecked("name", name);
+        checkNotNullParamChecked("value", value);
+        if (value.length == 0) throw CommonMessages.msg.emptyParam(name);
+        return value;
+    }
+
+    /**
+     * Check that the named parameter is not empty.  Use a standard exception message if it is.
+     *
+     * @param name the parameter name
+     * @param value the parameter value
+     * @return the value that was passed in
+     * @throws IllegalArgumentException if the value is empty
+     */
+    @NotNull
+    public static byte[] checkNotEmptyParam(String name, byte[] value) {
+        checkNotNullParamChecked("name", name);
+        checkNotNullParamChecked("value", value);
+        if (value.length == 0) throw CommonMessages.msg.emptyParam(name);
+        return value;
+    }
+
+    /**
+     * Check that the named parameter is not empty.  Use a standard exception message if it is.
+     *
+     * @param name the parameter name
+     * @param value the parameter value
+     * @return the value that was passed in
+     * @throws IllegalArgumentException if the value is empty
+     */
+    @NotNull
+    public static short[] checkNotEmptyParam(String name, short[] value) {
+        checkNotNullParamChecked("name", name);
+        checkNotNullParamChecked("value", value);
+        if (value.length == 0) throw CommonMessages.msg.emptyParam(name);
+        return value;
+    }
+
+    /**
+     * Check that the named parameter is not empty.  Use a standard exception message if it is.
+     *
+     * @param name the parameter name
+     * @param value the parameter value
+     * @return the value that was passed in
+     * @throws IllegalArgumentException if the value is empty
+     */
+    @NotNull
+    public static int[] checkNotEmptyParam(String name, int[] value) {
+        checkNotNullParamChecked("name", name);
+        checkNotNullParamChecked("value", value);
+        if (value.length == 0) throw CommonMessages.msg.emptyParam(name);
+        return value;
+    }
+
+    /**
+     * Check that the named parameter is not empty.  Use a standard exception message if it is.
+     *
+     * @param name the parameter name
+     * @param value the parameter value
+     * @return the value that was passed in
+     * @throws IllegalArgumentException if the value is empty
+     */
+    @NotNull
+    public static long[] checkNotEmptyParam(String name, long[] value) {
+        checkNotNullParamChecked("name", name);
+        checkNotNullParamChecked("value", value);
+        if (value.length == 0) throw CommonMessages.msg.emptyParam(name);
+        return value;
+    }
+
+    /**
+     * Check that the named parameter is not empty.  Use a standard exception message if it is.
+     *
+     * @param name the parameter name
+     * @param value the parameter value
+     * @return the value that was passed in
+     * @throws IllegalArgumentException if the value is empty
+     */
+    @NotNull
+    public static float[] checkNotEmptyParam(String name, float[] value) {
+        checkNotNullParamChecked("name", name);
+        checkNotNullParamChecked("value", value);
+        if (value.length == 0) throw CommonMessages.msg.emptyParam(name);
+        return value;
+    }
+
+    /**
+     * Check that the named parameter is not empty.  Use a standard exception message if it is.
+     *
+     * @param name the parameter name
+     * @param value the parameter value
+     * @return the value that was passed in
+     * @throws IllegalArgumentException if the value is empty
+     */
+    @NotNull
+    public static double[] checkNotEmptyParam(String name, double[] value) {
+        checkNotNullParamChecked("name", name);
+        checkNotNullParamChecked("value", value);
+        if (value.length == 0) throw CommonMessages.msg.emptyParam(name);
+        return value;
+    }
+
     /**
      * Check that the named parameter is greater than or equal to {@code min}.
      *
@@ -146,6 +291,32 @@ public final class Assert {
         if (actual < min) throw CommonMessages.msg.paramLessThan(name, min);
     }
 
+    /**
+     * Check that the named parameter is greater than or equal to {@code min}.
+     *
+     * @param name the parameter name
+     * @param min the minimum value
+     * @param actual the actual parameter value
+     * @throws IllegalArgumentException if the actual value is less than the minimum value
+     */
+    public static void checkMinimumParameter(String name, float min, float actual) throws IllegalArgumentException {
+        checkNotNullParamChecked("name", name);
+        if (actual < min) throw CommonMessages.msg.paramLessThan(name, min);
+    }
+
+    /**
+     * Check that the named parameter is greater than or equal to {@code min}.
+     *
+     * @param name the parameter name
+     * @param min the minimum value
+     * @param actual the actual parameter value
+     * @throws IllegalArgumentException if the actual value is less than the minimum value
+     */
+    public static void checkMinimumParameter(String name, double min, double actual) throws IllegalArgumentException {
+        checkNotNullParamChecked("name", name);
+        if (actual < min) throw CommonMessages.msg.paramLessThan(name, min);
+    }
+
     /**
      * Check that the named parameter is less than or equal to {@code max}.
      *
@@ -172,6 +343,32 @@ public final class Assert {
         if (actual > max) throw CommonMessages.msg.paramGreaterThan(name, max);
     }
 
+    /**
+     * Check that the named parameter is less than or equal to {@code max}.
+     *
+     * @param name the parameter name
+     * @param max the maximum value
+     * @param actual the actual parameter value
+     * @throws IllegalArgumentException if the actual value is greater than the minimum value
+     */
+    public static void checkMaximumParameter(String name, float max, float actual) throws IllegalArgumentException {
+        checkNotNullParamChecked("name", name);
+        if (actual > max) throw CommonMessages.msg.paramGreaterThan(name, max);
+    }
+
+    /**
+     * Check that the named parameter is less than or equal to {@code max}.
+     *
+     * @param name the parameter name
+     * @param max the maximum value
+     * @param actual the actual parameter value
+     * @throws IllegalArgumentException if the actual value is greater than the minimum value
+     */
+    public static void checkMaximumParameter(String name, double max, double actual) throws IllegalArgumentException {
+        checkNotNullParamChecked("name", name);
+        if (actual > max) throw CommonMessages.msg.paramGreaterThan(name, max);
+    }
+
     /**
      * Check that the given offset and length fall completely within the bounds of the given array.
      *
